@@ -222,7 +222,8 @@ default_arches = set()
 
 
 def _select_multiple_architectures(ui, arches):
-    """Interactively select from a menu of architectures & descriptions
+    """
+    Interactively select from a menu of architectures & descriptions
 
     Parameters
     ----------
@@ -236,6 +237,8 @@ def _select_multiple_architectures(ui, arches):
     None or list of str
         None when cancelled, or the selected architectures otherwise
     """
+    if not arches:
+        return
     return ui.select_multiple(
         'Which architectures would you like to select?',
         {arch: arch_descriptions.get(arch, '') for arch in arches},
@@ -1473,7 +1476,8 @@ SELECT_TAGS = {
 
 
 def select_tags(ui, taglist, check, value):
-    """Select tags based on checks
+    """
+    Select tags based on checks
 
     Parameters
     ----------
@@ -1492,7 +1496,7 @@ def select_tags(ui, taglist, check, value):
         new taglist
     """
     for tag, select_tag in SELECT_TAGS[check].items():
-        if select_tag(ui, value):
+        if select_tag(ui, value) and tag not in taglist:
             taglist += [tag]
     return taglist
 
@@ -1504,7 +1508,8 @@ SELECT_OTHER_TAGS = {
 
 
 def select_other_tags():
-    """Suggest tags to select when other tags are selected
+    """
+    Suggest tags to select when other tags are selected
 
     Parameters
     ----------
@@ -1579,7 +1584,8 @@ SORT_TAGS = {
 
 
 def sort_tags(tags):
-    """Sort tags based on checks
+    """
+    Sort tags based on checks
 
     Parameters
     ----------
@@ -1629,8 +1635,10 @@ SHOW_ARCHES = {
 }
 
 
-def _handle_arch_tag(mode, ui, pseudos, taglist, _locals):
+def _handle_arch_tag(mode, ui, pseudos, taglist, locals):
     taglist.remove('arch')
+    if locals['notatty']:
+        return
     # Show system architecture(s)
     if mode >= utils.MODE.STANDARD:
         arches = utils.get_arch()
@@ -1638,13 +1646,15 @@ def _handle_arch_tag(mode, ui, pseudos, taglist, _locals):
         arches = arches.split(',')
         arches = {arch.strip() for arch in arches}
         arches = {arch for arch in arches if arch in arch_usertags}
-    arches |= SHOW_ARCHES.get(mode, set())
+        arches |= SHOW_ARCHES.get(mode, set())
+    else:
+        arches = SHOW_ARCHES.get(mode, set())
     arches = _select_multiple_architectures(ui, arches)
     if arches:
         _apply_architectures(ui, pseudos, arches)
         if 'd-i' in taglist:
             _apply_di_architectures(ui, pseudos, arches)
-    return arches
+    return
 
 
 HANDLE_TAGS = {
@@ -1654,7 +1664,8 @@ HANDLE_TAGS = {
 
 
 def handle_tags(mode, ui, pseudos, taglist, locals):
-    """Handle tags with extra requirements
+    """
+    Handle tags with extra requirements
 
     Parameters
     ----------
