@@ -93,13 +93,13 @@ fhs_directories = ['/', '/usr', '/usr/share', '/var', '/usr/X11R6',
                    '/usr/man', '/usr/doc', '/usr/bin']
 
 # A map between codenames and suites
-CODENAME2SUITE = {'jessie': 'oldoldoldoldstable',
-                  'stretch': 'oldoldoldstable',
-                  'buster': 'oldoldstable',
-                  'bullseye': 'oldstable',
-                  'bookworm': 'stable',
-                  'trixie': 'testing',
-                  'forky': 'next-testing',
+CODENAME2SUITE = {'stretch': 'oldoldoldoldstable',
+                  'buster': 'oldoldoldstable',
+                  'bullseye': 'oldoldstable',
+                  'bookworm': 'oldstable',
+                  'trixie': 'stable',
+                  'forky': 'testing',
+                  'duke': 'next-testing',
                   'sid': 'unstable',
                   'experimental': 'experimental'}
 SUITE2CODENAME = dict([(suite, codename) for codename, suite in list(CODENAME2SUITE.items())])
@@ -907,7 +907,7 @@ def get_source_version(srcname):
     except apt.apt_pkg.Error as e:
         print(f"Cannot look up source package: '{e}'")
     # do not guess if there are multiple versions to choose from
-    if len(versions) == 1:
+    if len(set(versions)) == 1:
         return versions[0]
     return None
 
@@ -1173,6 +1173,30 @@ def get_dependency_info(package, depends, rel="depends on"):
     return depinfo
 
 
+def has_multiarch_same(src_package):
+    """Check if a source package has any binary packages with Multi-Arch: same
+
+    Parameters
+    ----------
+    src_package : str
+        the source package to find binary packages for
+
+    Returns
+    -------
+    bool
+        Indicates whether Multi-Arch: same was found (True) or not (False)
+    """
+    cache = apt.apt_pkg.Cache(None)
+    src = apt.apt_pkg.SourceRecords()
+    src.lookup(src_package)
+    for bin_package in src.binaries:
+        if bin_package in cache:
+            for version in cache[bin_package].version_list:
+                if version.multi_arch & version.MULTI_ARCH_SAME:
+                    return True
+    return False
+
+
 def get_changed_config_files(conffiles, nocompress=False):
     """
     Get information about modified config files
