@@ -444,6 +444,7 @@ class TestBugreportBody(unittest.TestCase):
 
         message = """Subject: unblock: reportbug/4.12.6
 Package: release.debian.org
+Usertags: duplicate
 User: release.debian.org@packages.debian.org
 Usertags: unblock
 random text between pseudoheader lines
@@ -452,6 +453,7 @@ Justification: line with too long content
 Severity: normal
 Morph: cool
 Control: testcontrol1
+User: ftp.debian.org@packages.debian.org
 source: reportbug
 Control: testcontrol2
 Continuation:
@@ -521,11 +523,13 @@ Shell: /bin/sh linked to /bin/bash"""
             'Source: reportbug',
             'Severity: normal',
             'Justification: line with too long content',
-            'User: release.debian.org@packages.debian.org',
-            'Usertags: unblock',
             'X-Debbugs-Cc: debian-reportbug@lists.debian.org, root@localhost',
             'Morph: cool',
+            'Usertags: duplicate',
+            'User: release.debian.org@packages.debian.org',
+            'Usertags: unblock',
             'Control: testcontrol1',
+            'User: ftp.debian.org@packages.debian.org',
             'Control: testcontrol2',
         ]
         cleanmessage = """some text before further head-like line
@@ -714,7 +718,11 @@ class TestEditor(unittest.TestCase):
 
 
 class TestSearch(unittest.TestCase):
-    def test_search_pipe(self):
+    @unittest.skipUnless(
+        os.path.exists('/usr/bin/dlocate'),
+        'dlocate not installed',
+    )
+    def test_search_pipe_dlocate(self):
         f = 'reportbug'
 
         dlocate = True
@@ -725,6 +733,9 @@ class TestSearch(unittest.TestCase):
         self.assertEqual(dloc, dlocate)
         self.assertGreater(len(res), 0)
 
+    def test_search_pipe_dpkg(self):
+        f = 'reportbug'
+
         dlocate = False
         pipe, dloc = utils.search_pipe(f, dlocate)
         res = pipe.readlines()
